/** 高亮搜索字的指令: 遍历dom内所有的文字节点，替换匹配为高亮节点
 *@example
 * <div v-highlight-query='test'>
 *   ......包含众多的dom, test .......
 * </div>
 * @example 输出为
 * <div class="tiny-hl-query">
 *  ....   <span class="tiny-hl-query-node">test</span>   ....
 * </div>
 *
 *  注意： 1、模板中，所有文字的地方需要使用同一个标签包裹起来，避免还原时误伤
 *         <div v-highlight-query='test'>
 *              这里一段话 {{ somevalue}}     <tiny-select>...</tiny-select>
 *           ^^^                        ^^^
 *          </div>
 *         这样的写法不合适，会造成文本节点与非文本节点共享一个父节点的。
 *         需要将 ^^^ 之间的内容，用标签包裹一下
 *        2、指令不能直接包含文字节点。 避免vue编译优化带来的一个问题。
 *          <div v-highlight-query='test'>
 *            {{ someValue }}
 *          </div>
 *          需要用任意标签，比如 <span> 包裹一下 someValue
 *  */
declare const _default: {
    mounted: (el: HTMLElement, binding: {
        value: string;
    }) => void;
    beforeUpdate: (el: HTMLElement) => void;
    updated: (el: HTMLElement, binding: {
        value: string;
    }) => void;
    inserted: (el: HTMLElement, binding: {
        value: string;
    }) => void;
    update: (el: HTMLElement) => void;
    componentUpdated: (el: HTMLElement, binding: {
        value: string;
    }) => void;
};
export default _default;
